Built-in Engine
===============

The default Gmsh kernel with basic geometry construction functions.
For advanced geometries it is recommended to use the openCASCADE kernel.

.. automodule:: pygmsh.geo

Geometry
--------
.. automodule:: pygmsh.geo.geometry
    :members:
    :undoc-members:
    :show-inheritance:
